@@ -1,15 +1,15 @@
 package Crypt::Passphrase::Encoder;
-$Crypt::Passphrase::Encoder::VERSION = '0.016';
+$Crypt::Passphrase::Encoder::VERSION = '0.017';
 use strict;
 use warnings;
 
 use parent 'Crypt::Passphrase::Validator';
 
-use Crypt::URandom;
+use Crypt::URandom 0.037;
 
 sub random_bytes {
 	my ($self, $count) = @_;
-	return Crypt::URandom::urandom($count);
+	return Crypt::URandom::urandom_ub($count);
 }
 
 sub crypt_subtypes;
@@ -24,10 +24,6 @@ sub accepts_hash {
 	return $hash =~ $self->{accepts_hash};
 }
 
-sub binary_safe {
-	return 1;
-}
-
 1;
 
 #ABSTRACT: Base class for Crypt::Passphrase encoders
@@ -44,33 +40,57 @@ Crypt::Passphrase::Encoder - Base class for Crypt::Passphrase encoders
 
 =head1 VERSION
 
-version 0.016
+version 0.017
 
 =head1 DESCRIPTION
 
 This is a base class for password encoders. It is a subclass of C<Crypt::Passphrase::Validator>.
 
-=head1 METHODS
+=head1 SUBCLASSING
 
-=head2 hash_password($password)
+=head2 MANDATORY METHODS
 
-This hashes a password. Note that this will return a new value each time since it uses a unique hash every time.
+It expects the subclass to implement the following four methods:
 
-=head2 needs_rehash($hash)
+=head3 hash_password
 
-This method will return true if the password needs a rehash. This may either mean it's using a different hashing algoritm, or because it's using different parameters. This should be overloaded in your subclass.
+ $encoder->hash_password($password)
 
-=head2 crypt_subtypes()
+This hashes a C<$password>. Note that this will typically return a different value each time since it uses a unique salt every time.
+
+=head3 verify_password
+
+ $encoder->verify_password($password, $hash)
+
+This checks if a C<$password> satisfies C<$hash>.
+
+=head3 needs_rehash
+
+ $encoder->needs_rehash($hash)
+
+This method will return true if the password hash needs a rehash. This may either mean it's using a different hashing algoritm, or because it's using different parameters.
+
+=head3 crypt_subtypes
+
+ $encoder->crypt_subtypes
 
 This method returns the types of crypt entries this validator supports. This is used to implement C<accepts_hash>.
 
-=head2 binary_safe()
+=head2 PROVIDED METHODS
 
-This method returns true if the encoder can take arbitrary binary inputs.
+It provides the following methods to aid in implementing encoders:
 
-=head2 random_bytes($count)
+=head3 random_bytes
 
-This is a utility method provided by the base class to aid in generating a good salt.
+ $encoder->random_bytes($count)
+
+This is a utility method to aid in generating a good salt.
+
+=head3 secure_compare
+
+ $encoder->secure_compare($left, $right)
+
+This compares two strings in a way that resists timing attacks.
 
 =head1 AUTHOR
 
