@@ -1,5 +1,5 @@
 package Crypt::Passphrase::SHA1::Base64;
-$Crypt::Passphrase::SHA1::Base64::VERSION = '0.016';
+$Crypt::Passphrase::SHA1::Base64::VERSION = '0.017';
 use strict;
 use warnings;
 
@@ -40,25 +40,20 @@ Crypt::Passphrase::SHA1::Base64 - Validate against base64ed SHA1 hashes with Cry
 
 =head1 VERSION
 
-version 0.016
+version 0.017
+
+=head1 SYNOPSIS
+
+ my $passphrase = Crypt::Passphrase->new(
+     encoder    => 'Argon2',
+     validators => [ 'SHA1::Base64' ],
+ );
 
 =head1 DESCRIPTION
 
 This module implements a validator for base64-encoded SHA-1 hashes.
 
-=head1 METHODS
-
-=head2 new()
-
-This creates a new SHA-1 validator. It takes no arguments.
-
-=head2 accepts_hash($hash)
-
-This (heuristically) determines if we may be dealing with a base64 encoded sha1 sum.
-
-=head2 verify_hash($password, $hash)
-
-This determines if the password matches the hash when SHA1'ed.
+This has no configuration and will try to match any value that looks like 20 bytes encoded in base64.
 
 =head1 AUTHOR
 
