@@ -1,5 +1,5 @@
 package Crypt::Passphrase::System;
-$Crypt::Passphrase::System::VERSION = '0.016';
+$Crypt::Passphrase::System::VERSION = '0.017';
 use strict;
 use warnings;
 
@@ -20,10 +20,10 @@ my @possibilities = (
 	['y' , '$y$j8T$'          , 16, '$y$j9T$F5Jx5fExrKuPp53xLKQ..1$tnSYvahCwPBHKZUspmcxMfb0.WiB9W.zEaKlOBL35rC'                       ],
 );
 
-my (%algorithm, %salt_for, $default);
+my (%algorithm, $default);
 for my $row (@possibilities) {
 	my ($name, $setting, $salt_size, $value) = @{$row};
-	my $hash = eval { crypt('password', $value) };
+	my $hash = eval { crypt 'password', $value };
 	if (defined $hash and $hash eq $value) {
 		$algorithm{$name} = { settings => $setting, salt_size => $salt_size };
 		$default = $name;
@@ -66,7 +66,7 @@ sub _encode_crypt64 {
 	my $npadbytes = 2 - ($nbytes + 2) % 3;
 	$bytes .= "\0" x $npadbytes;
 	my $digits = '';
-	for(my $i = 0; $i < $nbytes; $i += 3) {
+	for (my $i = 0; $i < $nbytes; $i += 3) {
 		my $v = ord(substr $bytes, $i, 1) |
 			(ord(substr $bytes, $i + 1, 1) << 8) |
 			(ord(substr $bytes, $i + 2, 1) << 16);
@@ -84,7 +84,7 @@ sub hash_password {
 	my ($self, $password) = @_;
 	my $salt = $self->random_bytes($self->{salt_size});
 	my $encoded_salt = _encode_crypt64($salt);
-	return crypt($password, "$self->{settings}$encoded_salt\$");
+	return crypt $password, "$self->{settings}$encoded_salt\$";
 }
 
 my $descrypt = qr{ \A [./0-9A-Za-z]{13} \z }x;
@@ -105,7 +105,7 @@ sub needs_rehash {
 
 sub verify_password {
 	my ($class, $password, $hash) = @_;
-	my $new_hash = crypt($password, $hash);
+	my $new_hash = crypt $password, $hash;
 	return $class->secure_compare($hash, $new_hash);
 }
 
@@ -125,7 +125,7 @@ Crypt::Passphrase::System - An system crypt() encoder for Crypt::Passphrase
 
 =head1 VERSION
 
-version 0.016
+version 0.017
 
 =head1 SYNOPSIS
 
@@ -139,6 +139,8 @@ Note that the supported algorithms depend entirely on your platform. The only op
 
 By default it uses the first supported algorithm in this list: C<yescript>, C<scrypt>, C<bcrypt>, C<SHAcrypt>, C<MD5crypt> and C<descrypt>.
 
+=head2 CONFIGURATION
+
 =head1 METHODS
 
 =head2 new(%args)
@@ -161,22 +163,10 @@ This sets the salt size for algorithm, it defaults to something that should be s
 
 =back
 
-=head2 hash_password($password)
-
-This hashes the passwords with argon2 according to the specified settings and a random salt (and will thus return a different result each time).
-
-=head2 needs_rehash($hash)
-
-This returns true if the hash uses a different cipher, or if any of the parameters are different than desired by the encoder.
-
-=head2 crypt_subtypes()
+=head2 SUPPORTED CRYPT TYPES
 
 This returns whatever crypt types it can discover on your system.
 
-=head2 verify_password($password, $hash)
-
-This will check if a password matches linux crypt hash.
-
 =head1 AUTHOR
 
 Leon Timmermans <leont@cpan.org>
